@@ -6,19 +6,29 @@
 
 extern void background_init(void);
 
+static gchar *background_image = NULL;
+
+const struct poptOption options [] = {
+	{ "background-image", 'b', POPT_ARG_STRING, &background_image, 0,
+	  N_("Set background image."), N_("IMAGE-FILE") },
+	{NULL, '\0', 0, NULL, 0}
+};
+
 gint
 main (gint argc, char *argv[])
 {
 	GnomeClient *client = NULL;
         GnomeClientFlags flags;
-	gchar *session_args[2];
+	gchar *session_args[3];
 	int token, init_results;
+	poptContext ctx;
+	char **args;
 
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 	
 	init_results = gnome_capplet_init("background-properties", VERSION,
-					  argc, argv, NULL, 0, NULL);
+					  argc, argv, options, 0, &ctx);
 
 	if (init_results < 0) {
                 g_warning ("an initialization error occurred while "
@@ -27,6 +37,16 @@ main (gint argc, char *argv[])
                 exit (1);
 	}
 
+	if (background_image) {
+		gnome_config_set_string ("/Background/Default/wallpaper",
+					 background_image);
+		gnome_config_sync ();
+
+		/* this goes somewhere else eventually */
+		background_imlib_init ();
+		background_properties_init();
+	}
+
 	client = gnome_master_client ();
 	flags = gnome_client_get_flags(client);
 
