@@ -62,7 +62,7 @@ screensaver_load ()
                 dpmsmins = 9999;
         else if (dpmsmins < 1)
                 dpmsmins = 1;
-        dpms = gnome_config_get_bool ("/Screensaver/Default/dpms=true");
+        dpms = gnome_config_get_bool ("/Screensaver/Default/dpms=false");
         password = gnome_config_get_bool ("/Screensaver/Default/password=true");
         screensaver = gnome_config_get_string_with_default ("/Screensaver/Default/mode", &defval);
         if (defval) {
@@ -534,6 +534,12 @@ monitor_expose_callback (GtkWidget *monitor, GdkEventButton *event, void *data)
                        _(random_screensaver),
                        strlen (_(random_screensaver)));
 }
+void
+monitor_died_callback (GtkWidget *check, void *data)
+{
+        /*g_print ("it died (booo hoo);\n");*/
+}
+
 void
 insert_text_callback (GtkEditable    *editable, const gchar    *text,
                            gint length, gint *position,
@@ -643,7 +649,6 @@ dialog_callback (GtkWidget *dialog, gint button, screensaver_data *newsd)
                         attributes.override_redirect = TRUE;
                         sswin = gdk_window_new (NULL, &attributes, GDK_WA_X|GDK_WA_Y|GDK_WA_NOREDIR);
                 }
-                g_print ("setting it all up\n");
                 gtk_signal_connect (GTK_OBJECT (dialog), "key_press_event", (GtkSignalFunc) ssaver_callback, sswin);
                 gtk_signal_connect (GTK_OBJECT (dialog), "button_press_event", (GtkSignalFunc) ssaver_callback, sswin);
                 XSelectInput (GDK_WINDOW_XDISPLAY (sswin), GDK_WINDOW_XWINDOW (sswin), ButtonPressMask | KeyPressMask);
@@ -733,9 +738,7 @@ ok_callback ()
                         g_string_append (command, "\"");
                 gnome_config_set_string ("/Screensaver/Default/command", command->str);
                 g_string_append (command, " &");
-                g_print ("\n*\n*\n*\n*running:%s:\n*\n*\n*\n", command->str);
                 system (command->str);
-                g_print ("done........\n");
                 g_string_free (command, TRUE);
         }
         if (dpms) {
@@ -787,7 +790,6 @@ try_callback ()
         GString *command;
         gchar temp[10];
         
-        g_print ("nuking xscreensaver2\n");
         system ("xscreensaver-command -exit");
 
         
