@@ -494,18 +494,12 @@ init_screensaver_data (screensaver_data *sd)
         /* We set up the prefix for most of our gnome_config stuff. */
         prefix = g_strconcat ("=", sd->desktop_filename, "=", NULL);
         gnome_config_push_prefix (prefix);
-        g_print ("prefix:%s:\n", prefix);
         /* We determine the current args */
         tempstring = gnome_config_get_string_with_default ("Screensaver Data/DefaultFlags", NULL);
-        g_print ("tempstring:%s:\n", tempstring);
         gnome_config_pop_prefix ();
         tempstring2 = g_strconcat ("/Screensaver/", sd->name, "/args=", tempstring ,NULL);
         g_free (tempstring);
         sd->args = gnome_config_get_string_with_default (tempstring2, NULL);
-        if (sd->args)
-                g_print ("%s\nsd->args|%s|\n", tempstring2, sd->args);
-        else
-                g_print ("yea!\n"); 
         g_free (tempstring2);
 
         /* We determine the setup layout. */
