@@ -151,6 +151,7 @@ get_demo_frame()
         gtk_frame_set_shadow_type (GTK_FRAME (inner_frame), GTK_SHADOW_IN);
 
         monitor = gtk_drawing_area_new ();
+        gtk_signal_connect (GTK_OBJECT (monitor), "destroy", monitor_died_callback, NULL);
         gtk_widget_set_usize (monitor, 200, 150);
 	gtk_container_set_border_width (GTK_CONTAINER (inner_frame), GNOME_PAD_SMALL);
         gtk_container_add (GTK_CONTAINER (retval), inner_frame);
@@ -245,7 +246,7 @@ main (int argc, char **argv)
                 
                 /* and now, a shameful reuse of variables to handle dpm. (: */
                 mypid = 0;
-                mypid = gnome_config_get_bool ("/Screensaver/Default/dpms=true");
+                mypid = gnome_config_get_bool ("/Screensaver/Default/dpms=false");
                 if (mypid) {
                         mypid = gnome_config_get_string ("/Screensaver/Default/dpmsmins=20");
                         mypid += gnome_config_get_string ("/Screensaver/Default/waitmins=20");
