@@ -50,7 +50,7 @@ ui_apply (void)
 #define NUM_BUTTONBOX_STYLES 5
 
 static const gchar * const buttonbox_style_names[] = {
-  N_("Default Gtk setting [FIXME - Describe this better]"),
+  N_("Default Gtk setting"),
   N_("Spread buttons out"),
   N_("Put buttons on edges"),
   N_("Left-justify buttons"),
@@ -149,7 +149,7 @@ make_option_menu(GtkWidget * vbox, const gchar * labeltext,
   GtkWidget * menuitem;
   GtkWidget * hbox;
   GtkWidget * label;
-  gint i;
+  gint i, def = 0; 
 
   option_menu = gtk_option_menu_new();
   menu = gtk_menu_new();
@@ -163,13 +163,15 @@ make_option_menu(GtkWidget * vbox, const gchar * labeltext,
                          GTK_SIGNAL_FUNC(callback), 
                          GINT_TO_POINTER (i) );
     if ( i == (*getfunc)() ) {
-      gtk_option_menu_set_history ( GTK_OPTION_MENU(option_menu), i );
+      def = i;
     }
     ++i;
   }
 
   gtk_option_menu_set_menu ( GTK_OPTION_MENU(option_menu), menu );
 
+  gtk_option_menu_set_history ( GTK_OPTION_MENU(option_menu), def );
+
   hbox = gtk_hbox_new (FALSE, 0);
 
   label = gtk_label_new(labeltext);
@@ -333,18 +335,24 @@ ui_setup (GtkWidget *old, GtkWidget *the_capplet)
     		gtk_check_button_new_with_label(_("Dialog buttons have icons"));
 		  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), 
     		                          gnome_config_get_bool("/Gnome/Icons/ButtonUseIcons=true"));
-		  gtk_signal_connect(GTK_OBJECT(button), "toggled",
-    		                 GTK_SIGNAL_FUNC(checkbutton_bool_cb),
-        		             "/Gnome/Icons/ButtonUseIcons");
+		  gtk_signal_connect_full(GTK_OBJECT(button), "toggled",
+					  GTK_SIGNAL_FUNC(checkbutton_bool_cb),
+					  NULL,
+					  g_strdup("/Gnome/Icons/ButtonUseIcons"),
+					  (GtkDestroyNotify)g_free,
+					  FALSE,FALSE);
 		  gtk_box_pack_start ( GTK_BOX(vbox), button, FALSE, FALSE, 0  );
 
 		  button = 
 		    gtk_check_button_new_with_label(_("Menu items have icons"));
 		  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), 
 		                              gnome_config_get_bool("/Gnome/Icons/MenusUseIcons=true"));
-		  gtk_signal_connect(GTK_OBJECT(button), "toggled",
-    		                 GTK_SIGNAL_FUNC(checkbutton_bool_cb),
-        		             "/Gnome/Icons/MenusUseIcons");
+		  gtk_signal_connect_full(GTK_OBJECT(button), "toggled",
+					  GTK_SIGNAL_FUNC(checkbutton_bool_cb),
+					  NULL,
+					  g_strdup("/Gnome/Icons/MenusUseIcons"),
+					  (GtkDestroyNotify)g_free,
+					  FALSE,FALSE);
 		  gtk_box_pack_start ( GTK_BOX(vbox), button, FALSE, FALSE, 0  );
 
 		  gtk_widget_show_all(vbox);
@@ -386,8 +394,9 @@ main (int argc, char **argv)
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 	
-	gnome_capplet_init ("ui-properties", VERSION, argc,
-											argv, NULL, 0, NULL);
+  if (gnome_capplet_init ("ui-properties", VERSION, argc,
+                          argv, NULL, 0, NULL) < 0)
+    error (1);
 
 	the_capplet = capplet_widget_new();
   ui_read ();
