@@ -22,6 +22,8 @@ GdkBitmap *mask3;*/
 extern gchar *init_cap;
 extern GnomeAppBar *status_bar;
 
+#define SMALL_ICON_SIZE 20
+#if 0
 gint button_press (GtkCTree *ctree, GdkEventButton *event, gpointer data)
 {
         if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) {
@@ -30,7 +32,7 @@ gint button_press (GtkCTree *ctree, GdkEventButton *event, gpointer data)
         }
         return TRUE;
 }
-
+#endif
 static void
 init_tree_handler (GtkWidget *ctree, GdkEvent *event, node_data *data)
 {
@@ -40,7 +42,7 @@ init_tree_handler (GtkWidget *ctree, GdkEvent *event, node_data *data)
                 gnome_appbar_push (GNOME_APPBAR (status_bar), (data->gde->comment));
         else
                 gnome_appbar_push (GNOME_APPBAR (status_bar), (data->gde->name));
-        launch_capplet (data);
+        launch_capplet (data, TRUE);
 }
 gint compare_last_dir (gchar *first, gchar *second)
 {
@@ -185,27 +187,51 @@ generate_tree_helper (GtkCTree *ctree, GtkCTreeNode *parent, GNode *node)
         char *text[2];
         node_data *data;
         gchar exec_collapsed[100];
+        gchar *icon;
+        GnomePixmap *icon_gpixmap;
+        GdkPixmap *icon_pixmap, *icon_mask;
         
 
         text[1] = NULL;
-
         for (i = node;i;i = i->next) {
+                icon_pixmap=NULL;
+                icon_mask=NULL;
+                icon=NULL;
+                icon_gpixmap = NULL;
                 if (i->data && ((GnomeDesktopEntry *)i->data)->name)
                         text[0] = ((GnomeDesktopEntry *)i->data)->name;
                 else
                         text[0] = "*MISSINGNAME*";
+#if 0
+                if ((i->data) && ((GnomeDesktopEntry *)i->data)->icon)
+                        icon = ((GnomeDesktopEntry *)i->data)->icon;
+                if (icon && g_file_exists (icon)) 
+                        icon_gpixmap = (GnomePixmap *)gnome_pixmap_new_from_file_at_size(icon,
+                                                                                         SMALL_ICON_SIZE,
+                                                                                         SMALL_ICON_SIZE);
+                if (icon_gpixmap) {
+                        icon_pixmap = icon_gpixmap->pixmap;
+                        icon_mask   = icon_gpixmap->mask;
+                }
+#endif
                 if (i->data && (!strcmp(((GnomeDesktopEntry *)i->data)->type,"Directory")))
-                        child = gtk_ctree_insert_node (ctree,parent,NULL, text, 3, NULL, NULL,NULL,NULL,FALSE,FALSE);
+                        child = gtk_ctree_insert_node (ctree,parent,NULL, text, 3, 
+                                                       icon_pixmap, icon_mask,
+                                                       icon_pixmap, icon_mask, FALSE,FALSE);
                 else 
-                        child = gtk_ctree_insert_node (ctree,parent,NULL, text, 3, NULL, NULL,NULL,NULL,TRUE,FALSE);
+                        child = gtk_ctree_insert_node (ctree,parent,NULL, text, 3,  
+                                                       icon_pixmap, icon_mask,
+                                                       icon_pixmap, icon_mask, TRUE,FALSE);
                 data = g_malloc (sizeof (node_data));
                 data->gde = (GnomeDesktopEntry *)i->data;
                 data->socket = NULL;
                 data->node = child;
                 data->id = -1;
+                data->capplet = NULL;
                 data->ctree = ctree;
                 data->notetab_id = -1;
                 data->modified = FALSE;
+                data->state = CAPPLET_INACTIVE;
                 gtk_ctree_node_set_row_data (ctree, child, data);
                 exec_collapsed[0] = '\0';
                 if (data->gde->exec && init_cap) {
@@ -213,8 +239,10 @@ generate_tree_helper (GtkCTree *ctree, GtkCTreeNode *parent, GNode *node)
                                 strncat (exec_collapsed, data->gde->exec[j], 99);
                         if (!strcmp (exec_collapsed, init_cap)) {
                                 GtkCTreeNode *temp = child;
+/*
                                 for (;temp;temp = GTK_CTREE_ROW (temp)->parent)
                                         gtk_ctree_expand (ctree, temp);
+*/
                                 gtk_ctree_select (ctree, child);
                                 
                                 gtk_signal_connect_after (GTK_OBJECT (ctree), "expose_event",
@@ -225,6 +253,8 @@ generate_tree_helper (GtkCTree *ctree, GtkCTreeNode *parent, GNode *node)
 
                 if (i->children)
                         generate_tree_helper (ctree, child, i->children);
+                if (parent == NULL)
+                        gtk_ctree_expand_recursive (ctree, child);
         }
 }
 GtkWidget *
@@ -237,9 +267,11 @@ generate_tree ()
         gchar *user_prefix;
 
         retval = gtk_ctree_new (1, 0);
+#if 0
+        /* I don't remember what this was for, but away it goes... -jrb */
         gtk_signal_connect (GTK_OBJECT (retval), "button_press_event",
                             GTK_SIGNAL_FUNC (button_press), NULL);
-        
+#endif   
         /* First thing we want to do is to check directories to create the menus */
         
         gtk_clist_set_row_height(GTK_CLIST (retval),20);
@@ -247,9 +279,9 @@ generate_tree ()
         gtk_ctree_set_expander_style (GTK_CTREE (retval), GTK_CTREE_EXPANDER_SQUARE);
         gtk_clist_set_column_width(GTK_CLIST (retval), 0, 150);
 
-        gtk_ctree_set_indent (GTK_CTREE (retval), 10);
+        gtk_ctree_set_indent (GTK_CTREE (retval), 15);
         gtk_clist_set_column_auto_resize (GTK_CLIST (retval), 0, TRUE);
-        //gtk_widget_set_usize (retval, 200, 375);
+        /*gtk_widget_set_usize (retval, 200, 375);*/
         gtk_clist_set_selection_mode(GTK_CLIST(retval), GTK_SELECTION_BROWSE);
         gtk_signal_connect( GTK_OBJECT (retval),"tree_select_row", GTK_SIGNAL_FUNC (selected_row_callback), NULL);
 
@@ -280,6 +312,7 @@ generate_tree ()
         }
         g_free (root_prefix);
         g_free (user_prefix);
+        gtk_ctree_sort_recursive (GTK_CTREE (retval), NULL);
         return retval;
 }
 
@@ -301,6 +334,19 @@ selected_row_callback (GtkWidget *widget, GtkCTreeNode *node, gint column)
         else
                 gnome_appbar_push (GNOME_APPBAR (status_bar), (gde->name));
 
-        if (event) //&& event->type == GDK_2BUTTON_PRESS)
-                launch_capplet (data);
+        /* && event->type == GDK_2BUTTON_PRESS) */
+        if (event){
+                GtkWidget *grabbing_widget;
+
+                while ((grabbing_widget = gtk_grab_get_current ()) != NULL)
+                        gtk_grab_remove (grabbing_widget);
+                while (gtk_events_pending ())
+                        gtk_main_iteration ();
+                if (gdk_pointer_is_grabbed ())
+                        gdk_pointer_ungrab (GDK_CURRENT_TIME);
+                gdk_flush ();
+                
+                launch_capplet (data, TRUE);
+        }
 }
+
